# Aliases for OS
if type pacman &>/dev/null; then
	if (( $+commands[yaourt] )); then
		alias yaconf='yaourt -C'
		alias yaupg='yaourt -Syua'
		alias yasu='yaourt -Syua --noconfirm'
		alias yain='yaourt -S'
		alias yains='yaourt -U'
		alias yare='yaourt -R'
		alias yarem='yaourt -Rns'
		alias yarep='yaourt -Si'
		alias yareps='yaourt -Ss'
		alias yaloc='yaourt -Qi'
		alias yalocs='yaourt -Qs'
		alias yalst='yaourt -Qe'
		alias yaorph='yaourt -Qtd'
		alias yainsd='yaourt -S --asdeps'
		alias yamir='yaourt -Syy'
		alias yaupd='yaourt -Sy'
	fi

	alias pacupg='sudo pacman -Syu'
	alias pacin='sudo pacman -S'
	alias pacins='sudo pacman -U'
	alias pacre='sudo pacman -R'
	alias pacrem='sudo pacman -Rns'
	alias pacrep='pacman -Si'
	alias pacreps='pacman -Ss'
	alias pacloc='pacman -Qi'
	alias paclocs='pacman -Qs'
	alias pacinsd='sudo pacman -S --asdeps'
	alias pacmir='sudo pacman -Syy'
	alias paclsorphans='sudo pacman -Qdt'
	alias pacrmorphans='sudo pacman -Rs $(pacman -Qtdq)'
	alias pacfileupg='sudo pacman -Fy'
	alias pacfiles='pacman tFs'
	alias pacupd='sudo pacman -Sy'

	paclist() {
		LC_ALL=C pacman -Qei $(pacman -Qu | cut -d " " -f 1) | \
		awk 'BEGIN {FS=":"} /^Name/{printf("\033[1;36m%s\033[1;37m", $2)} /^Description/{print $2}'
	}

	pacdisowned() {
		emulate -L zsh

		tmp=${TMPDIR-/tmp}/pacman-disowned-$UID-$$
		db=$tmp/db
		fs=$tmp/fs

		mkdir "$tmp"
		trap  'rm -rf "$tmp"' EXIT

		pacman -Qlq | sort -u > "$db"

		find /bin /etc /lib /sbin /usr ! -name lost+found  \( -type d -printf '%p/\n' -o -print \) | sort > "$fs"

		comm -23 "$fs" "$db"
	}

	pacmanallkeys() {
		emulate -L zsh
		curl -s https://www.archlinux.org/people/{developers,trustedusers}/ | \
		awk -F\" '(/pgp.mit.edu/) { sub(/.*search=0x/,""); print $1}' | xargs sudo pacman-key --recv-keys
	}

	pacmansignkeys() {
		emulate -L zsh
		for key in $*; do
			sudo pacman-key --recv-keys $key
			sudo pacman-key --lsign-key $key
			printf 'trust\n3\n' | sudo gpg --homedir /etc/pacman.d/gnupg --no-permission-warning --command-fd 0 --edit-key $key
		done
	}
fi

if type apt-get &>/dev/null; then
	apt_pref='apt-get'
	apt_upgr='upgrade'

	if [[ -e $( which -p sudo 2>&1 ) ]]; then use_sudo=1; fi

	alias age='apt-get'
	alias acs="apt-cache search"
	alias afs='apt-file search --regexp'
	alias asrc='apt-get source'
	alias app='apt-cache policy'

	alias aac='sudo apt-get autoclean'
	alias abd='sudo apt-get build-dep'
	alias ac='sudo apt-get clean'
	alias ad='sudo apt-get update'
	alias adg='sudo apt-get update && sudo apt-get upgrade'
	alias adu='sudo apt-get update && sudo apt-get dist-upgrade'
	alias afu='sudo apt-file update'
	alias ag='sudo apt-get upgrade'
	alias ai='sudo apt-get install'
	alias ail="sed -e 's/  */ /g' -e 's/ *//' | cut -s -d ' ' -f 1 | "' xargs sudo apt-get install'
	alias ap='sudo apt-get purge'
	alias ar='sudo apt-get remove'
	alias ads='sudo apt-get dselect-upgrade'
	alias dia='sudo dpkg -i ./*.deb'
	alias di='sudo dpkg -i'

	apt_pref_compdef() {
		local f fb
		f="_apt_pref_${2}"

		eval "function ${f}() {
			shift words;
			service=\"apt-get\";
			words=(\"apt-get\" '$2' \$words);
			((CURRENT++))
			_apt
			}"
		compdef "$f" "$1"
	}

	apt_pref_compdef aac "autoclean"
	apt_pref_compdef abd "build-dep"
	apt_pref_compdef ac  "clean"
	apt_pref_compdef ad  "update"
	apt_pref_compdef afu "update"
	apt_pref_compdef ag  "upgrade"
	apt_pref_compdef ai  "install"
	apt_pref_compdef ail "install"
	apt_pref_compdef ap  "purge"
	apt_pref_compdef ar  "remove"
	apt_pref_compdef ads "dselect-upgrade"

	apt-history () {
		case "$1" in
			install)
				zgrep --no-filename 'install ' $(ls -rt /var/log/dpkg*)
				;;
			upgrade|remove)
				zgrep --no-filename $1 $(ls -rt /var/log/dpkg*)
				;;
			rollback)
				zgrep --no-filename upgrade $(ls -rt /var/log/dpkg*) | grep "$2" -A10000000 | grep "$3" -B10000000 | awk '{print $4"="$5}'
				;;
			list)
				zgrep --no-filename '' $(ls -rt /var/log/dpkg*)
				;;
			*)
				echo "Parameters:"
				echo " install - Lists all packages that have been installed."
				echo " upgrade - Lists all packages that have been upgraded."
				echo " remove - Lists all packages that have been removed."
				echo " rollback - Lists rollback information."
				echo " list - Lists all contents of dpkg logs."
				;;
		esac
	}
fi
